﻿using ProtoBuf;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Runtime.Serialization;
using System.Runtime.Serialization.Formatters.Binary;
using System.Text;

namespace Server
{
    //The data structure by which the server and the client interact with 
    //each other
    public class Data
    {
        public string strName
        {
            get;
            set;
        }      //Name by which the client logs into the room
        public string strMessage { get; set; }   //Message text
        public Command cmdCommand { get; set; }  //Command type (login, logout, send message, etcetera)
        public byte[] msgArray
        {
            get;
            set;
        }

        bool binary { get; set; }

        //Default constructor
        public Data(bool binary = false)
        {
            this.cmdCommand = Command.Null;
            this.strMessage = null;
            this.msgArray = null;
            this.strName = null;
            this.binary = binary;
        }

        public void SetMsgBinaryObject(object obj)
        {
            this.msgArray = ObjStream.SerializeToArray(obj);
        }
        public T GetMsgBinaryObject<T>() where T : class
        {
            T t = ObjStream.DeserializeFromArray<T>(msgArray) as T;
            return t;
        }
        //Converts the bytes into an object of type Data
        public Data(byte[] data, bool binary = false)
        {
            this.binary = binary;
            //The first four bytes are for the Command
            this.cmdCommand = (Command)BitConverter.ToInt32(data, 0);

            //The next four store the length of the name
            int nameLen = BitConverter.ToInt32(data, 4);

            //The next four store the length of the message
            int msgLen = BitConverter.ToInt32(data, 8);

            //This check makes sure that strName has been passed in the array of bytes
            if (nameLen > 0)
                this.strName = Encoding.UTF8.GetString(data, 12, nameLen);
            else
                this.strName = null;

            //This checks for a null message field
            if (msgLen > 0)
                if (binary)
                    this.msgArray = SubArray<byte>(data, 12 + nameLen, msgLen);
                else
                    this.strMessage = Encoding.UTF8.GetString(data, 12 + nameLen, msgLen);
            else
                this.strMessage = null;
        }
        public static T[] SubArray<T>(T[] data, int index, int length)
        {
            T[] result = new T[length];
            Array.Copy(data, index, result, 0, length);
            return result;
        }
        //Converts the Data structure into an array of bytes
        public byte[] ToByte()
        {
            List<byte> result = new List<byte>();

            //First four are for the Command
            result.AddRange(BitConverter.GetBytes((int)cmdCommand));

            //Add the length of the name
            if (strName != null)
                result.AddRange(BitConverter.GetBytes(strName.Length));
            else
                result.AddRange(BitConverter.GetBytes(0));

            //Length of the message
            if (binary && msgArray != null)
                result.AddRange(BitConverter.GetBytes(msgArray.Length));
            else if (strMessage != null)
                result.AddRange(BitConverter.GetBytes(strMessage.Length));
            else
                result.AddRange(BitConverter.GetBytes(0));

            //Add the name
            if (strName != null)
                result.AddRange(Encoding.UTF8.GetBytes(strName));

            //And, lastly we add the message text to our array of bytes
            if (binary)
            {
                if (msgArray != null)
                    result.AddRange(msgArray);
            }
            else
            {
                if (strMessage != null)
                    result.AddRange(Encoding.UTF8.GetBytes(strMessage));
            }
            return result.ToArray();
        }

        static class ObjStream
        {
            public static MemoryStream SerializeToStream(object obj) {
                MemoryStream stream = new MemoryStream();
                Serializer.Serialize(stream, obj);
                return stream;
            }
            public static byte[] SerializeToArray(object obj) {
                byte[] arr;
                using (MemoryStream stream = new MemoryStream()) {
                    Serializer.Serialize(stream, obj);
                    arr = stream.ToArray();
                }
                return arr;
            }
            public static object DeserializeFromStream(MemoryStream stream) {
                object o = Serializer.Deserialize<object>(stream);
                return o;
            }

            public static T DeserializeFromArray<T>(byte[] arr) {
                T o = Serializer.Deserialize<T>(new MemoryStream(arr));
                return o;
            }
        }
    }
}


