﻿//-----------------------------------------------------------------------
// <copyright file="SimpleAROrbit.cs" company="Google">
//
// Copyright 2016 Google Inc. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// </copyright>
//-----------------------------------------------------------------------
using System.Collections;
using UnityEngine;

/// <summary>
/// Simple class for rotating an object around another GameObject.
/// </summary>
public class SimpleAROrbit : MonoBehaviour
{
    /// <summary>
    /// The earth around which the moon orbits.
    /// </summary>
    public GameObject m_earth;

    /// <summary>
    /// The radius of orbit.
    /// </summary>
    public float m_radius = 2.0f;

    /// <summary>
    /// The speed at which to orbit.
    /// </summary>
    public float m_orbitSpeed = 10.0f;

    /// <summary>
    /// Update is called once per frame.
    /// </summary>
    private void Update()
    {
        // Rotate around the Earth
        Transform center = m_earth.transform;
        transform.RotateAround(center.position, transform.up, m_orbitSpeed * Time.deltaTime);
    }
}
