﻿using UnityEngine;
using System.Collections;
using UnityEngine.UI;

public class TargetGPS : MonoBehaviour
{
	private bool msgPopup = false;

	public GameObject msgUI;// = GameObject.FindGameObjectWithTag("MsgPopup");

	private float originalLatitude;
	private float originalLongitude;
	private float currentLongitude;
	private float currentLatitude;

	[SerializeField]
	private static float ulmanLat = 32.7779637f;
	[SerializeField]
	private static float ulmanLon = 35.0229148f;

	private GameObject distanceTextObject;
	private double distance;

	private bool setOriginalValues = true;

	private Vector3 targetPosition;
	private Vector3 originalPosition;
	private float distanceFloat;

	private float minDistance = 5.0f;

	private float speed = .1f;

	IEnumerator GetCoordinates()
	{
		//while true so this function keeps running once started.
		while (true)
		{
			// check if user has location service enabled
			if (!Input.location.isEnabledByUser)
				yield break;

			// Start service before querying location
			Input.location.Start(1f, .1f);

			// Wait until service initializes
			int maxWait = 20;
			while (Input.location.status == LocationServiceStatus.Initializing && maxWait > 0)
			{
				yield return new WaitForSeconds(1);
				maxWait--;
			}

			// Service didn't initialize in 20 seconds
			if (maxWait < 1)
			{
				//print("Timed out");
				yield break;
			}

			// Connection has failed
			if (Input.location.status == LocationServiceStatus.Failed)
			{
				//print("Unable to determine device location");
				yield break;
			}
			else
			{
				// Access granted and location value could be retrieved
				//print("Location: " + Input.location.lastData.latitude + " " + Input.location.lastData.longitude + " " + Input.location.lastData.altitude + " " + Input.location.lastData.horizontalAccuracy + " " + Input.location.lastData.timestamp);

				//if original value has not yet been set save coordinates of player on app start
				if (setOriginalValues)
				{
					originalLatitude = Input.location.lastData.latitude;
					originalLongitude = Input.location.lastData.longitude;
					setOriginalValues = false;
				}

				//overwrite current lat and lon everytime
				currentLatitude = Input.location.lastData.latitude;
				currentLongitude = Input.location.lastData.longitude;

				Calc(ulmanLat, ulmanLon, currentLatitude, currentLongitude);

			}
			Input.location.Stop();
		}
	}

	IEnumerator PopUP()
	{
		//msgUI = GameObject.FindGameObjectWithTag("MsgPopup");
		Debug.Log("POPUP Open");
		
		msgUI.SetActive(true);
		yield return new WaitForSeconds(10);
		msgUI.SetActive(false);

		Debug.Log("POPUP Close");

	}

	//calculates distance between two sets of coordinates, taking into account the curvature of the earth.
	public void Calc(float lat1, float lon1, float lat2, float lon2)
	{

		var R = 6378.137; // Radius of earth in KM
		var dLat = lat2 * Mathf.PI / 180 - lat1 * Mathf.PI / 180;
		var dLon = lon2 * Mathf.PI / 180 - lon1 * Mathf.PI / 180;
		float a = Mathf.Sin(dLat / 2) * Mathf.Sin(dLat / 2) +
		  Mathf.Cos(lat1 * Mathf.PI / 180) * Mathf.Cos(lat2 * Mathf.PI / 180) *
		  Mathf.Sin(dLon / 2) * Mathf.Sin(dLon / 2);
		var c = 2 * Mathf.Atan2(Mathf.Sqrt(a), Mathf.Sqrt(1 - a));
		distance = R * c;
		distance = distance * 1000f; // meters
									 //set the distance text on the canvas
		//distanceTextObject.GetComponent<Text>().text = "Distance: " + distance;
		//convert distance from double to float
		distanceFloat = (float)distance;
		//set the target position of the ufo, this is where we lerp to in the update function
		//targetPosition = originalPosition - new Vector3(0, 0, distanceFloat * 12);
		//distance was multiplied by 12 so I didn't have to walk that far to get the UFO to show up closer

	}

	void Start()
	{
		//start GetCoordinate() function 
		StartCoroutine("GetCoordinates");
		//initialize target and original position
		targetPosition = GPSEncoder.GPSToUCS(ulmanLat, ulmanLon);
		originalPosition = transform.position;

	}

	void Update()
	{
		if(true || /*true*/distanceFloat <= minDistance)
		{
			if (!msgPopup)
			{
				msgPopup = true;
				StartCoroutine("PopUP");// WaitForSeconds());
			}
		}
		//linearly interpolate from current position to target position
		//transform.position = Vector3.Lerp(transform.position, targetPosition, speed);
		//rotate by 1 degree about the y axis every frame
		//transform.eulerAngles += new Vector3(0, 1f, 0);

	}
}

public sealed class GPSEncoder
{

	/////////////////////////////////////////////////
	//////-------------Public API--------------//////
	/////////////////////////////////////////////////

	/// <summary>
	/// Convert UCS (X,Y,Z) coordinates to GPS (Lat, Lon) coordinates
	/// </summary>
	/// <returns>
	/// Returns Vector2 containing Latitude and Longitude
	/// </returns>
	/// <param name='position'>
	/// (X,Y,Z) Position Parameter
	/// </param>
	public static Vector2 USCToGPS(Vector3 position)
	{
		return GetInstance().ConvertUCStoGPS(position);
	}

	/// <summary>
	/// Convert GPS (Lat, Lon) coordinates to UCS (X,Y,Z) coordinates
	/// </summary>
	/// <returns>
	/// Returns a Vector3 containing (X, Y, Z)
	/// </returns>
	/// <param name='gps'>
	/// (Lat, Lon) as Vector2
	/// </param>
	public static Vector3 GPSToUCS(Vector2 gps)
	{
		return GetInstance().ConvertGPStoUCS(gps);
	}

	/// <summary>
	/// Convert GPS (Lat, Lon) coordinates to UCS (X,Y,Z) coordinates
	/// </summary>
	/// <returns>
	/// Returns a Vector3 containing (X, Y, Z)
	/// </returns>
	public static Vector3 GPSToUCS(float latitude, float longitude)
	{
		return GetInstance().ConvertGPStoUCS(new Vector2(latitude, longitude));
	}

	/// <summary>
	/// Change the relative GPS offset (Lat, Lon), Default (0,0), 
	/// used to bring a local area to (0,0,0) in UCS coordinate system
	/// </summary>
	/// <param name='localOrigin'>
	/// Referance point.
	/// </param>
	public static void SetLocalOrigin(Vector2 localOrigin)
	{
		GetInstance()._localOrigin = localOrigin;
	}

	/////////////////////////////////////////////////
	//////---------Instance Members------------//////
	/////////////////////////////////////////////////

	#region Singleton
	private static GPSEncoder _singleton;

	private GPSEncoder()
	{

	}

	private static GPSEncoder GetInstance()
	{
		if (_singleton.Equals(null))
		{
			_singleton = new GPSEncoder();
		}
		return _singleton;
	}
	#endregion

	#region Instance Variables
	private Vector2 _localOrigin = Vector2.zero;
	private float _LatOrigin { get { return _localOrigin.x; } }
	private float _LonOrigin { get { return _localOrigin.y; } }

	private float metersPerLat;
	private float metersPerLon;
	#endregion

	#region Instance Functions
	private void FindMetersPerLat(float lat) // Compute lengths of degrees
	{
		float m1 = 111132.92f;    // latitude calculation term 1
		float m2 = -559.82f;        // latitude calculation term 2
		float m3 = 1.175f;      // latitude calculation term 3
		float m4 = -0.0023f;        // latitude calculation term 4
		float p1 = 111412.84f;    // longitude calculation term 1
		float p2 = -93.5f;      // longitude calculation term 2
		float p3 = 0.118f;      // longitude calculation term 3

		lat = lat * Mathf.Deg2Rad;

		// Calculate the length of a degree of latitude and longitude in meters
		metersPerLat = m1 + (m2 * Mathf.Cos(2 * (float)lat)) + (m3 * Mathf.Cos(4 * (float)lat)) + (m4 * Mathf.Cos(6 * (float)lat));
		metersPerLon = (p1 * Mathf.Cos((float)lat)) + (p2 * Mathf.Cos(3 * (float)lat)) + (p3 * Mathf.Cos(5 * (float)lat));
	}

	private Vector3 ConvertGPStoUCS(Vector2 gps)
	{
		FindMetersPerLat(_LatOrigin);
		float zPosition = metersPerLat * (gps.x - _LatOrigin); //Calc current lat
		float xPosition = metersPerLon * (gps.y - _LonOrigin); //Calc current lat
		return new Vector3((float)xPosition, 0, (float)zPosition);
	}

	private Vector2 ConvertUCStoGPS(Vector3 position)
	{
		FindMetersPerLat(_LatOrigin);
		Vector2 geoLocation = new Vector2(0, 0);
		geoLocation.x = (_LatOrigin + (position.z) / metersPerLat); //Calc current lat
		geoLocation.y = (_LonOrigin + (position.x) / metersPerLon); //Calc current lon
		return geoLocation;
	}
	#endregion
}
